Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(80)

Unified Diff: chrome/browser/views/browser_actions_container.h

Issue 337035: Replace ExtensionAction with ExtensionAction2. (Closed)
Patch Set: Remove todo Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/tab_contents/tab_contents.cc ('k') | chrome/browser/views/browser_actions_container.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/views/browser_actions_container.h
diff --git a/chrome/browser/views/browser_actions_container.h b/chrome/browser/views/browser_actions_container.h
index 756de0ae9fba9879da8680575006355819069488..a3ba6fe5e8406f827c6c15ddfa30831329bfe901 100644
--- a/chrome/browser/views/browser_actions_container.h
+++ b/chrome/browser/views/browser_actions_container.h
@@ -17,7 +17,7 @@
class BrowserActionsContainer;
class Extension;
-class ExtensionAction2;
+class ExtensionAction;
class ExtensionPopup;
class Profile;
class ToolbarView;
@@ -26,7 +26,7 @@ class ToolbarView;
// BrowserActionButton
// The BrowserActionButton is a specialization of the MenuButton class.
// It acts on a ExtensionAction2, in this case a BrowserAction and handles
// loading the image for the button asynchronously on the file thread to
class BrowserActionButton : public views::MenuButton,
public views::ButtonListener,
@@ -36,7 +36,7 @@ class BrowserActionButton : public views::MenuButton,
BrowserActionButton(Extension* extension, BrowserActionsContainer* panel);
~BrowserActionButton();
- ExtensionAction2* browser_action() const { return browser_action_; }
+ ExtensionAction* browser_action() const { return browser_action_; }
Extension* extension() { return extension_; }
// Called to update the display to match the browser action's state.
@@ -79,9 +79,9 @@ class BrowserActionButton : public views::MenuButton,
// If the image from the browser action needs to be loaded, load it.
void LoadImage();
// The browser action this view represents. The ExtensionAction2 is not owned
// by this class.
- ExtensionAction2* browser_action_;
+ ExtensionAction* browser_action_;
// The extension associated with the browser action we're displaying.
Extension* extension_;
« no previous file with comments | « chrome/browser/tab_contents/tab_contents.cc ('k') | chrome/browser/views/browser_actions_container.cc » ('j') | no next file with comments »
@@ -26,7 +26,7 @@ class ToolbarView;
// BrowserActionButton
// The BrowserActionButton is a specialization of the MenuButton class.
-// It acts on a ExtensionAction2, in this case a BrowserAction and handles
+// It acts on a ExtensionAction, in this case a BrowserAction and handles
// loading the image for the button asynchronously on the file thread to
class BrowserActionButton : public views::MenuButton,
@@ -79,9 +79,9 @@ class BrowserActionButton : public views::MenuButton,
// If the image from the browser action needs to be loaded, load it.
void LoadImage();
- // The browser action this view represents. The ExtensionAction2 is not owned
+ // The browser action this view represents. The ExtensionAction is not owned
// by this class.

Powered by Google App Engine
This is Rietveld 408576698